@@ -11,24 +11,19 @@ from ..config import Config
 class BlackLinter(Linter):
     def __init__(self, config: Config) -> None:
         self.config = {
-            'line_length': config.line_length,
-            'skip_string_normalization': True,
+            "line_length": config.line_length,
         }
         if config.exclude:
-            self.config['exclude'] = '|'.join(
-                expr.replace('.', r'\.').replace('*', '.*')
-                for expr in config.exclude.split(',')
+            self.config["exclude"] = "|".join(
+                expr.replace(".", r"\.").replace("*", ".*")
+                for expr in config.exclude.split(",")
             )
 
     def dump_config(self, dst: Path) -> None:
-        with open(dst / 'black.toml', 'w') as out:
-            out.write('[tool.black]\n')
+        with open(dst / "black.toml", "w") as out:
+            out.write("[tool.black]\n")
             out.write(f'line_length = {self.config["line_length"]}\n')
-            out.write(
-                'skip-string-normalization = '
-                f'{str(self.config["skip_string_normalization"]).lower()}\n'
-            )
-            if 'exclude' in self.config:
+            if "exclude" in self.config:
                 out.write(f'exclude = "{self.config["exclude"]}"\n')
 
     def run(self, paths: List[Path]) -> List[str]:
@@ -39,7 +34,7 @@ class BlackLinter(Linter):
 
     @property
     def name(self):
-        return 'black'
+        return "black"
 
     def _run(self, paths: List[Path], check: bool) -> List[str]:
         # Hardcoded params
@@ -57,9 +52,8 @@ class BlackLinter(Linter):
         versions = set()
         mode = black.Mode(
             target_versions=versions,
-            line_length=self.config['line_length'],
+            line_length=self.config["line_length"],
             is_pyi=False,
-            string_normalization=not self.config['skip_string_normalization'],
             experimental_string_processing=False,
         )
         report = Report(check=check)
@@ -70,7 +64,7 @@ class BlackLinter(Linter):
             quiet=quiet,
             verbose=verbose,
             include=include,
-            exclude=self.config.get('exclude', black.DEFAULT_EXCLUDES),
+            exclude=self.config.get("exclude", black.DEFAULT_EXCLUDES),
             force_exclude=force_exclude,
             report=report,
         )
@@ -104,9 +98,9 @@ class Report(black.Report):
 
     def done(self, src: Path, changed: black.Changed) -> None:
         if changed is black.Changed.YES and self.check:
-            self.errors.append(f'{src}: would reformat')
+            self.errors.append(f"{src}: would reformat")
             self.change_count += 1
 
     def failed(self, src: Path, message: str) -> None:
-        self.errors.append(f'{src}: cannot format')
+        self.errors.append(f"{src}: cannot format")
         self.failure_count += 1
